@@ -4,7 +4,7 @@
 	 * the functions provided by the database driver exclusively, and hence
 	 * will work with any database without modification.
 	 *
-	 * $Id: Reports.php,v 1.11 2004/07/01 07:15:11 chriskl Exp $
+	 * $Id: Reports.php,v 1.11.2.2 2005/10/18 03:15:57 chriskl Exp $
 	 */
 
 	class Reports {
@@ -22,7 +22,7 @@
 			if ($rs->recordCount() != 1) $status = -1;
 			else {
 				// Create a new database access object.
-				$this->driver = &$misc->getDatabaseAccessor($this->reports_db);
+				$this->driver = $misc->getDatabaseAccessor($this->reports_db);
 				// Reports database should have been created in public schema
 				if ($this->driver->hasSchemas()) $this->driver->setSchema('public');
 				$status = 0;
@@ -33,7 +33,7 @@
 		 * Finds all reports
 		 * @return A recordset
 		 */
-		function &getReports() {
+		function getReports() {
 			global $conf;
 			// Filter for owned reports if necessary
 			if ($conf['owned_reports_only']) {
@@ -54,7 +54,7 @@
 		 * @param $report_id The ID of the report to find
 		 * @return A recordset
 		 */
-		function &getReport($report_id) {			
+		function getReport($report_id) {			
 			$sql = $this->driver->getSelectSQL('ppa_reports',
 				array('report_id', 'report_name', 'db_name', 'date_created', 'created_by', 'descr', 'report_sql'),
 				array('report_id' => $report_id), array('report_id' => '='), array());
