@@ -9,11 +9,12 @@
 	 * @param $return_desc The return link name
 	 * @param $page The current page
 	 *
-	 * $Id: display.php,v 1.46.2.1 2005/02/09 11:31:49 chriskl Exp $
+	 * $Id: display.php,v 1.46.2.3 2005/10/18 03:15:57 chriskl Exp $
 	 */
 
-      // Prevent timeouts on large result sets
-      set_time_limit(0);
+	// Prevent timeouts
+	if (!ini_get('safe_mode')) set_time_limit(0);
+
 	// Include application functions
 	include_once('./libraries/lib.inc.php');
 
@@ -37,8 +38,8 @@
 			$misc->printTitle($lang['streditrow']);
 			$misc->printMsg($msg);
 
-			$attrs = &$data->getTableAttributes($_REQUEST['table']);
-			$rs = &$data->browseRow($_REQUEST['table'], $key);
+			$attrs = $data->getTableAttributes($_REQUEST['table']);
+			$rs = $data->browseRow($_REQUEST['table'], $key);
 
 			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 			$elements = 0;
@@ -255,7 +256,7 @@
 		}
 
 		// Retrieve page from query.  $max_pages is returned by reference.
-		$rs = &$data->browseQuery($type, 
+		$rs = $data->browseQuery($type, 
 			isset($object) ? $object : null, 
 			isset($_REQUEST['query']) ? $_REQUEST['query'] : null, 
 			$_REQUEST['sortkey'], $_REQUEST['sortdir'], $_REQUEST['page'],
