@@ -3,7 +3,7 @@
 	/**
 	 * List tables in a database
 	 *
-	 * $Id: tables.php,v 1.68 2004/10/11 10:29:15 jollytoad Exp $
+	 * $Id: tables.php,v 1.68.2.1 2005/10/18 03:15:57 chriskl Exp $
 	 */
 
 	// Include application functions
@@ -28,7 +28,7 @@
 		switch ($_REQUEST['stage']) {
 			case 1:
 				// Fetch all tablespaces from the database
-				if ($data->hasTablespaces()) $tablespaces = &$data->getTablespaces();
+				if ($data->hasTablespaces()) $tablespaces = $data->getTablespaces();
 				
 				$misc->printTrail('schema');
 				$misc->printTitle($lang['strcreatetable'], 'pg.table.create');
@@ -93,7 +93,7 @@
 					return;
 				}
 
-				$types = &$data->getTypes(true, false, true);
+				$types = $data->getTypes(true, false, true);
 	
 				$misc->printTrail('schema');
 				$misc->printTitle($lang['strcreatetable'], 'pg.table.create');
@@ -221,7 +221,7 @@
 			$misc->printTitle($lang['strselect'], 'pg.sql.select');
 			$misc->printMsg($msg);
 
-			$attrs = &$data->getTableAttributes($_REQUEST['table']);
+			$attrs = $data->getTableAttributes($_REQUEST['table']);
 
 			echo "<form action=\"$PHP_SELF\" method=\"post\" name=\"selectform\">\n";
 			if ($attrs->recordCount() > 0) {
@@ -330,7 +330,7 @@
 			$misc->printTitle($lang['strinsertrow'], 'pg.sql.insert');
 			$misc->printMsg($msg);
 
-			$attrs = &$data->getTableAttributes($_REQUEST['table']);
+			$attrs = $data->getTableAttributes($_REQUEST['table']);
 
 			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 			if ($attrs->recordCount() > 0) {
@@ -530,7 +530,7 @@
 		$misc->printTabs('schema','tables');
 		$misc->printMsg($msg);
 		
-		$tables = &$data->getTables();
+		$tables = $data->getTables();
 		
 		$columns = array(
 			'table' => array(
