@@ -3,7 +3,7 @@
 	/**
 	 * Manage types in a database
 	 *
-	 * $Id: types.php,v 1.25 2004/09/07 13:58:21 jollytoad Exp $
+	 * $Id: types.php,v 1.25.2.2 2005/10/18 03:15:57 chriskl Exp $
 	 */
 
 	// Include application functions
@@ -21,21 +21,21 @@
 		global $PHP_SELF, $lang;
 
 		// Get type (using base name)
-		$typedata = &$data->getType($_REQUEST['type']);
+		$typedata = $data->getType($_REQUEST['type']);
 
 		$misc->printTrail('type');
 		$misc->printTitle($lang['strproperties'], 'pg.type');
 		$misc->printMsg($msg);
 		
+		function attPre(&$rowdata) {
+			global $data;
+			$rowdata->f['+type'] = $data->formatType($rowdata->f['type'], $rowdata->f['atttypmod']);
+		}
+
 		if ($typedata->recordCount() > 0) {
 			switch ($typedata->f['typtype']) {
 			case 'c':
-				function attPre(&$rowdata) {
-					global $data;
-					$rowdata->f['+type'] = $data->formatType($rowdata->f['type'], $rowdata->f['atttypmod']);
-				}
-				
-				$attrs = &$data->getTableAttributes($_REQUEST['type']);
+				$attrs = $data->getTableAttributes($_REQUEST['type']);
 				
 				$columns = array(
 					'field' => array(
@@ -171,7 +171,7 @@
 					return;
 				}
 
-				$types = &$data->getTypes(true, false, true);
+				$types = $data->getTypes(true, false, true);
 
 				$misc->printTrail('type');
 				$misc->printTitle($lang['strcreatecomptype'], 'pg.type.create');
@@ -282,8 +282,8 @@
 		if (!isset($_POST['typstorage'])) $_POST['typstorage'] = $data->typStorageDef;
 
 		// Retrieve all functions and types in the database
-		$funcs = &$data->getFunctions(true);
-		$types = &$data->getTypes(true);
+		$funcs = $data->getFunctions(true);
+		$types = $data->getTypes(true);
 
 		$misc->printTrail('schema');
 		$misc->printTitle($lang['strcreatetype'], 'pg.type.create');
@@ -400,7 +400,7 @@
 		$misc->printTabs('schema','types');
 		$misc->printMsg($msg);
 		
-		$types = &$data->getTypes();
+		$types = $data->getTypes();
 
 		$columns = array(
 			'type' => array(
