@@ -3,7 +3,7 @@
 	/**
 	 * Manage views in a database
 	 *
-	 * $Id: views.php,v 1.42 2004/06/04 05:26:35 chriskl Exp $
+	 * $Id: views.php,v 1.51.2.1 2005/10/18 03:15:57 chriskl Exp $
 	 */
 
 	// Include application functions
@@ -23,10 +23,11 @@
 		global $PHP_SELF;
 
 		if ($confirm) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strviews']}: ", $misc->printVal($_REQUEST['view']), ": {$lang['strselect']}</h2>\n";
+			$misc->printTrail('view');
+			$misc->printTitle($lang['strselect'], 'pg.sql.select');
 			$misc->printMsg($msg);
 
-			$attrs = &$data->getTableAttributes($_REQUEST['view']);
+			$attrs = $data->getTableAttributes($_REQUEST['view']);
 
 			echo "<form action=\"$PHP_SELF\" method=\"get\" name=\"selectform\">\n";
 			if ($attrs->recordCount() > 0) {
@@ -45,7 +46,7 @@
 				echo "<table>\n<tr>";
 
 				// Output table header
-				echo "<tr><th class=\"data\">{$lang['strshow']}</th><th class=\"data\">{$lang['strfield']}</th>";
+				echo "<tr><th class=\"data\">{$lang['strshow']}</th><th class=\"data\">{$lang['strcolumn']}</th>";
 				echo "<th class=\"data\">{$lang['strtype']}</th><th class=\"data\">{$lang['stroperator']}</th>";
 				echo "<th class=\"data\">{$lang['strvalue']}</th></tr>";
 
@@ -86,6 +87,7 @@
 
 			echo "<p><input type=\"hidden\" name=\"action\" value=\"selectrows\" />\n";
 			echo "<input type=\"hidden\" name=\"view\" value=\"", htmlspecialchars($_REQUEST['view']), "\" />\n";
+			echo "<input type=\"hidden\" name=\"subject\" value=\"view\" />\n";
 			echo $misc->form;
 			echo "<input type=\"submit\" name=\"select\" value=\"{$lang['strselect']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
@@ -129,9 +131,11 @@
 		global $PHP_SELF, $lang, $_reload_browser;
 
 		if ($confirm) { 
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strviews']}: ", $misc->printVal($_REQUEST['view']), ": {$lang['strdrop']}</h2>\n";
+			$misc->printTrail('view');
+			$misc->printTitle($lang['strdrop'],'pg.view.drop');
+			
+			echo "<p>", sprintf($lang['strconfdropview'], $misc->printVal($_REQUEST['view'])), "</p>\n";
 			
-			echo "<p>", sprintf($lang['strconfdropview'], $misc->printVal($_REQUEST['view'])), "</p>\n";	
 			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 			echo "<input type=\"hidden\" name=\"action\" value=\"drop\" />\n";
 			echo "<input type=\"hidden\" name=\"view\" value=\"", htmlspecialchars($_REQUEST['view']), "\" />\n";
@@ -170,16 +174,17 @@
 			if (!isset($_REQUEST['formView'])) $_REQUEST['formView'] = '';
 			if (!isset($_REQUEST['formComment'])) $_REQUEST['formComment'] = '';
 			
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strviews']}: {$lang['strcreateviewwiz']}</h2>\n";		
+			$misc->printTrail('schema');
+			$misc->printTitle($lang['strcreateviewwiz'], 'pg.view.create');
 			$misc->printMsg($msg);
 			
-			$tblCount = sizeof($_POST['formTables']);						
+			$tblCount = sizeof($_POST['formTables']);
 			//unserialize our schema/table information and store in arrSelTables
 			for ($i = 0; $i < $tblCount; $i++) {
 				$arrSelTables[] = unserialize($_POST['formTables'][$i]);
-			}									
+			}
 			
-			$linkCount = $tblCount;						
+			$linkCount = $tblCount;
 			// If we can get foreign key info then get our linking keys
 			if ($data->hasForeignKeysInfo()) {
 				$rsLinkKeys = $data->getLinkingKeys($arrSelTables);
@@ -196,8 +201,8 @@
 					$data->setSchema($arrSelTables[$i]['schemaname']);
 				}
 				
-				$attrs = &$data->getTableAttributes($arrSelTables[$i]['tablename']);
-				while (!$attrs->EOF) {						
+				$attrs = $data->getTableAttributes($arrSelTables[$i]['tablename']);
+				while (!$attrs->EOF) {
 					if ($data->hasSchemas() ) {
 						$arrFields["{$arrSelTables[$i]['schemaname']}.{$arrSelTables[$i]['tablename']}.{$attrs->f['attname']}"] = serialize(array('schemaname' => $arrSelTables[$i]['schemaname'], 'tablename' => $arrSelTables[$i]['tablename'], 'fieldname' => $attrs->f['attname']) );
 					}
@@ -208,11 +213,11 @@
 				}
 				
 				//reset back to our original schema in case we switched from it
-				if ($data->hasSchemas() ) {				
+				if ($data->hasSchemas() ) {
 					$data->setSchema($curSchema);
 				}
-			}						
-			asort($arrFields);			
+			}
+			asort($arrFields);
 			
 			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 			echo "<table>\n";
@@ -223,7 +228,7 @@
 			echo "</td>\n</tr>\n";
 			echo "<tr><th class=\"data\">{$lang['strcomment']}</th></tr>";
 			echo "<tr>\n<td class=\"data1\">\n";
-			// View comments			
+			// View comments
 			echo "<textarea name=\"formComment\" rows=\"3\" cols=\"32\" wrap=\"virtual\">", 
 				htmlspecialchars($_REQUEST['formComment']), "</textarea>\n";
 			echo "</td>\n</tr>\n";
@@ -231,23 +236,23 @@
 			
 			// Output selector for fields to be retrieved from view
 			echo "<table>\n";
-			echo "<tr><th class=\"data\">{$lang['strfields']}</th></tr>";
-			echo "<tr>\n<td class=\"data1\">\n";			
+			echo "<tr><th class=\"data\">{$lang['strcolumns']}</th></tr>";
+			echo "<tr>\n<td class=\"data1\">\n";
 			echo GUI::printCombo($arrFields, 'formFields[]', false, '', true);
-			echo "</td>\n</tr>\n</table>\n<br />\n";						
-									
-			// Output the Linking keys combo boxes only if we detect linking keys
+			echo "</td>\n</tr>\n</table>\n<br />\n";
+			
+			// Output the Linking keys combo boxes
 			echo "<table>\n";
-			echo "<tr><th class=\"data\">{$lang['strviewlink']}</th></tr>";					
+			echo "<tr><th class=\"data\">{$lang['strviewlink']}</th></tr>";
 			$rowClass = 'data1';
 			for ($i = 0; $i < $linkCount; $i++) {
 				// Initialise variables
 				if (!isset($formLink[$i]['operator'])) $formLink[$i]['operator'] = 'INNER JOIN';
 				echo "<tr>\n<td class=\"$rowClass\">\n";
-							
+				
 				if ($data->hasForeignKeysInfo() && !$rsLinkKeys->EOF) {
 					$curLeftLink = htmlspecialchars(serialize(array('schemaname' => $rsLinkKeys->f['p_schema'], 'tablename' => $rsLinkKeys->f['p_table'], 'fieldname' => $rsLinkKeys->f['p_field']) ) );
-					$curRightLink = htmlspecialchars(serialize(array('schemaname' => $rsLinkKeys->f['f_schema'], 'tablename' => $rsLinkKeys->f['f_table'], 'fieldname' => $rsLinkKeys->f['f_field']) ) );						
+					$curRightLink = htmlspecialchars(serialize(array('schemaname' => $rsLinkKeys->f['f_schema'], 'tablename' => $rsLinkKeys->f['f_table'], 'fieldname' => $rsLinkKeys->f['f_field']) ) );
 					$rsLinkKeys->moveNext();
 				}
 				else {
@@ -259,10 +264,10 @@
 				echo GUI::printCombo($data->joinOps, "formLink[$i][operator]", true, $formLink[$i]['operator']);
 				echo GUI::printCombo($arrFields, "formLink[$i][rightlink]", true, $curRightLink, false );
 				echo "</td>\n</tr>\n";
-				$rowClass = $rowClass == 'data1' ? 'data2' : 'data1';			
+				$rowClass = $rowClass == 'data1' ? 'data2' : 'data1';
 			}
 			echo "</table>\n<br />\n";
-								
+			
 			// Build list of available operators (infix only)
 			$arrOperators = array();
 			foreach ($data->selectOps as $k => $v) {
@@ -272,28 +277,28 @@
 			// Output additional conditions, note that this portion of the wizard treats the right hand side as literal values 
 			//(not as database objects) so field names will be treated as strings, use the above linking keys section to perform joins
 			echo "<table>\n";
-			echo "<tr><th class=\"data\">{$lang['strviewconditions']}</th></tr>";					
+			echo "<tr><th class=\"data\">{$lang['strviewconditions']}</th></tr>";
 			$rowClass = 'data1';
-			for ($i = 0; $i < $linkCount; $i++) {				
+			for ($i = 0; $i < $linkCount; $i++) {
 				echo "<tr>\n<td class=\"$rowClass\">\n";
 				echo GUI::printCombo($arrFields, "formCondition[$i][field]");
 				echo GUI::printCombo($arrOperators, "formCondition[$i][operator]", false, false);
 				echo "<input type=\"text\" name=\"formCondition[$i][txt]\" />\n";
 				echo "</td>\n</tr>\n";
 				$rowClass = $rowClass == 'data1' ? 'data2' : 'data1';
-			}			
+			}
 			echo "</table>\n";
-			echo "<p><input type=\"hidden\" name=\"action\" id=\"action\" value=\"save_create_wiz\" />\n";			
-			echo "<input type=\"submit\" value=\"{$lang['strnext']}\" />\n";
+			echo "<p><input type=\"hidden\" name=\"action\" id=\"action\" value=\"save_create_wiz\" />\n";
+			echo "<input type=\"submit\" value=\"{$lang['strcreate']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
-						
-			foreach ($arrSelTables AS $curTable) {				
+			
+			foreach ($arrSelTables AS $curTable) {
 				echo "<input type=\"hidden\" name=\"formTables[]\" id=\"formTables[]\" value=\"" . htmlspecialchars(serialize($curTable) ) . "\" />\n";
 			}
 			
 			echo $misc->form;
 			echo "</form>\n";
-		}	
+		}
 	}
 	
 	/**
@@ -302,9 +307,13 @@
 	function doWizardCreate($msg = '') {
 		global $data, $misc;
 		global $PHP_SELF, $lang;
-		$tables = &$data->getTables(true);				
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strviews']}: {$lang['strcreateviewwiz']}</h2>\n";		
+		
+		$tables = $data->getTables(true);
+		
+		$misc->printTrail('schema');
+		$misc->printTitle($lang['strcreateviewwiz'], 'pg.view.create');
 		$misc->printMsg($msg);
+		
 		echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 		echo "<table>\n";
 		echo "<tr><th class=\"data\">{$lang['strtables']}</th></tr>";		
@@ -313,13 +322,13 @@
 		$arrTables = array();
 		while (!$tables->EOF) {						
 			$arrTmp = array();
-			$arrTmp['schemaname'] = $tables->f['schemaname'];
-			$arrTmp['tablename'] = $tables->f['tablename'];
+			$arrTmp['schemaname'] = $tables->f['nspname'];
+			$arrTmp['tablename'] = $tables->f['relname'];
 			if ($data->hasSchemas() ) { //if schemas aren't available don't show them in the interface
-				$arrTables[$tables->f['schemaname'] . '.' . $tables->f['tablename']] = serialize($arrTmp);
+				$arrTables[$tables->f['nspname'] . '.' . $tables->f['relname']] = serialize($arrTmp);
 			}
 			else {
-				$arrTables[$tables->f['tablename']] = serialize($arrTmp);
+				$arrTables[$tables->f['relname']] = serialize($arrTmp);
 			}
 			$tables->moveNext();
 		}		
@@ -345,9 +354,8 @@
 		if (!isset($_REQUEST['formDefinition'])) $_REQUEST['formDefinition'] = 'SELECT ';
 		if (!isset($_REQUEST['formComment'])) $_REQUEST['formComment'] = '';
 		
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strviews']}: {$lang['strcreateview']}</h2>\n";
-		
-		//$misc->printHelp("/sql-createview.html#R2-SQL-CREATEVIEW-1");
+		$misc->printTrail('schema');
+		$misc->printTitle($lang['strcreateview'], 'pg.view.create');
 		$misc->printMsg($msg);
 		
 		echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
@@ -437,58 +445,58 @@
 							$arrRightLink = unserialize($curLink['rightlink']);
 							
 							$tbl1 = $data->hasSchemas() ? "\"{$arrLeftLink['schemaname']}\".\"{$arrLeftLink['tablename']}\"" : $arrLeftLink['tablename'];
-							$tbl2 = $data->hasSchemas() ? "\"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\"" : $arrLeftLink['tablename'];												
-													
+							$tbl2 = $data->hasSchemas() ? "\"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\"" : $arrRightLink['tablename'];
+							
 							if ( (!in_array($curLink, $arrJoined) && in_array($tbl1, $arrUsedTbls)) || !count($arrJoined) ) {
-															
+								
 								// Make sure for multi-column foreign keys that we use a table alias tables joined to more than once
 								// This can (and should be) more optimized for multi-column foreign keys
 								$adj_tbl2 = in_array($tbl2, $arrUsedTbls) ? "$tbl2 AS alias_ppa_" . mktime() : $tbl2;
-																						
-								if ($data->hasSchemas() ) {	
+								
+								if ($data->hasSchemas() ) {
 									$linkFields .= strlen($linkFields) ? "{$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['schemaname']}\".\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") " : "$tbl1 {$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['schemaname']}\".\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") ";
 								}
 								else {
 									$linkFields .= strlen($linkFields) ? "{$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") " : "$tbl1 {$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") ";
-								}								
+								}
 								
 								$arrJoined[] = $curLink;
 								if (!in_array($tbl1, $arrUsedTbls) )  $arrUsedTbls[] = $tbl1;
 								if (!in_array($tbl2, $arrUsedTbls) )  $arrUsedTbls[] = $tbl2;
-							}						
+							}
 						}
-						$j++;					
+						$j++;
 					}
-				}				
-			} 			
+				}
+			}
 			
 			//if linkfields has no length then either _POST['formLink'] was not set, or there were no join conditions 
 			//just select from all seleted tables - a cartesian join do a
 			if (!strlen($linkFields) ) {
 				foreach ($_POST['formTables'] AS $curTable) {
 					$arrTmp = unserialize($curTable);
-					if ($data->hasSchemas() ) {					
+					if ($data->hasSchemas() ) {
 						$linkFields .= strlen($linkFields) ? ", \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\"" : "\"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\"";
 					}
 					else {
 						$linkFields .= strlen($linkFields) ? ", \"{$arrTmp['tablename']}\"" : "\"{$arrTmp['tablename']}\"";
-					}				
-				}				
-			}			
+					}
+				}
+			}
 			
 			$addConditions = '';
 			if (is_array($_POST['formCondition']) ) {
 				foreach ($_POST['formCondition'] AS $curCondition) {
-					if (strlen($curCondition['field']) && strlen($curCondition['txt']) ) {						
+					if (strlen($curCondition['field']) && strlen($curCondition['txt']) ) {
 						$arrTmp = unserialize($curCondition['field']);
 						if ($data->hasSchemas() ) {
 							$addConditions .= strlen($addConditions) ? " AND \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['operator']} '{$curCondition['txt']}' " : " \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['operator']} '{$curCondition['txt']}' ";
-						}						
+						}
 						else {
 							$addConditions .= strlen($addConditions) ? " AND \"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['field']} {$curCondition['operator']} '{$curCondition['txt']}' " : " \"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['operator']} '{$curCondition['txt']}' ";
-						}						
-					}	
-				}		
+						}
+					}
+				}
 			}
 			
 			$viewQuery = "SELECT $selFields FROM $linkFields ";
@@ -501,10 +509,10 @@
 				$_reload_browser = true;
 				doDefault($lang['strviewcreated']);
 			}
-			else				
+			else
 				doSetParamsCreate($lang['strviewcreatedbad']);
 		}
-	}	
+	}
 	
 	/**
 	 * Show default list of views in the database
@@ -513,50 +521,62 @@
 		global $data, $misc, $conf;
 		global $PHP_SELF, $lang;
 		
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strviews']}</h2>\n";
+		$misc->printTrail('schema');
+		$misc->printTabs('schema','views');
 		$misc->printMsg($msg);
 		
-		$views = &$data->getViews();
+		$views = $data->getViews();
 		
-		if ($views->recordCount() > 0) {
-			echo "<table>\n";
-			echo "<tr><th class=\"data\">{$lang['strview']}</th><th class=\"data\">{$lang['strowner']}</th>";
-			echo "<th colspan=\"4\" class=\"data\">{$lang['stractions']}</th>\n";
-			if ($conf['show_comments']) echo "<th class=\"data\">{$lang['strcomment']}</th>";
-			echo "</tr>\n";
-			$i = 0;
-			while (!$views->EOF) {
-				// @@@@@@@@@ FIX THIS!!!!!
-				if ($data->hasSchemas() && isset($_REQUEST['schema'])) {
-					$data->fieldClean($_REQUEST['schema']);
-					$query = urlencode("SELECT * FROM \"{$_REQUEST['schema']}\".\"{$views->f[$data->vwFields['vwname']]}\"");
-				}
-				else
-					$query = urlencode("SELECT * FROM \"{$views->f[$data->vwFields['vwname']]}\"");
-				$count = urlencode("SELECT COUNT(*) AS total FROM \"{$views->f[$data->vwFields['vwname']]}\"");
-				$return_url = urlencode("views.php?{$misc->href}");
-				$id = (($i % 2) == 0 ? '1' : '2');
-				echo "<tr><td class=\"data{$id}\">", $misc->printVal($views->f[$data->vwFields['vwname']]), "</td>\n";
-				echo "<td class=\"data{$id}\">", $misc->printVal($views->f[$data->vwFields['vwowner']]), "</td>\n";
-				echo "<td class=\"opbutton{$id}\"><a href=\"display.php?{$misc->href}&query={$query}&count={$count}&return_url={$return_url}&return_desc=",
-					urlencode($lang['strback']), "\">{$lang['strbrowse']}</a></td>\n";
-				echo "<td class=\"opbutton{$id}\"><a href=\"$PHP_SELF?action=confselectrows&{$misc->href}&view=", urlencode($views->f[$data->vwFields['vwname']]), "\">{$lang['strselect']}</a></td>\n"; 
-				echo "<td class=\"opbutton{$id}\"><a href=\"viewproperties.php?{$misc->href}&view=", urlencode($views->f[$data->vwFields['vwname']]), "\">{$lang['strproperties']}</a></td>\n"; 
-				echo "<td class=\"opbutton{$id}\"><a href=\"$PHP_SELF?action=confirm_drop&{$misc->href}&view=", urlencode($views->f[$data->vwFields['vwname']]), "\">{$lang['strdrop']}</a></td>\n";
-				// Trim long comments
-				if (strlen($views->f[$data->vwFields['vwcomment']]) > $conf['max_chars']) {
-					$views->f[$data->vwFields['vwcomment']] = substr($views->f[$data->vwFields['vwcomment']], 0, $conf['max_chars'] - 1) . $lang['strellipsis'];
-				}
-				if ($conf['show_comments']) echo "<td class=\"data{$id}\">", $misc->printVal($views->f[$data->vwFields['vwcomment']]), "</td>\n";
-				echo "</tr>\n";
-				$views->moveNext();
-				$i++;
-			}
-			echo "</table>\n";
-		}
-		else {
-			echo "<p>{$lang['strnoviews']}</p>\n";
-		}
+		$columns = array(
+			'view' => array(
+				'title'	=> $lang['strview'],
+				'field'	=> 'relname',
+			),
+			'owner' => array(
+				'title'	=> $lang['strowner'],
+				'field'	=> 'relowner',
+			),
+			'actions' => array(
+				'title'	=> $lang['stractions'],
+			),
+			'comment' => array(
+				'title'	=> $lang['strcomment'],
+				'field'	=> 'relcomment',
+			),
+		);
+		
+		$actions = array(
+			'properties' => array(
+				'title' => $lang['strproperties'],
+				'url'	=> "redirect.php?section=view&amp;{$misc->href}&amp;",
+				'vars'	=> array('view' => 'relname'),
+			),
+			'browse' => array(
+				'title'	=> $lang['strbrowse'],
+				'url'	=> "display.php?{$misc->href}&amp;subject=view&amp;return_url=".urlencode("views.php?{$misc->href}")."&amp;return_desc=".urlencode($lang['strback'])."&amp;",
+				'vars'	=> array('view' => 'relname'),
+			),
+			'select' => array(
+				'title'	=> $lang['strselect'],
+				'url'	=> "{$PHP_SELF}?action=confselectrows&amp;{$misc->href}&amp;",
+				'vars'	=> array('view' => 'relname'),
+			),
+			
+// Insert is possible if the relevant rule for the view has been created.
+//			'insert' => array(
+//				'title'	=> $lang['strinsert'],
+//				'url'	=> "{$PHP_SELF}?action=confinsertrow&amp;{$misc->href}&amp;",
+//				'vars'	=> array('view' => 'relname'),
+//			),
+
+			'drop' => array(
+				'title'	=> $lang['strdrop'],
+				'url'	=> "{$PHP_SELF}?action=confirm_drop&amp;{$misc->href}&amp;",
+				'vars'	=> array('view' => 'relname'),
+			),
+		);
+		
+		$misc->printTable($views, $columns, $actions, $lang['strnoviews']);
 		
 		echo "<p><a class=\"navlink\" href=\"$PHP_SELF?action=create&{$misc->href}\">{$lang['strcreateview']}</a> |\n";
 		echo "<a class=\"navlink\" href=\"$PHP_SELF?action=wiz_create&{$misc->href}\">{$lang['strcreateviewwiz']}</a></p>\n";
